
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.1.30'
version = '1.1.30'
full_version = '1.1.30'
git_revision = '9d9b3d3472e7e1da084500a9c9697d96d1dff0c1'
release = True

if not release:
    version = full_version
    short_version += ".dev"
